pub struct StepSpec {
pub id: StepId,
pub type: StepType,
pub inputs: Value,
pub policy: Value,
pub execution: StepExecution,
pub slug: Option<String>,
pub trust: Option<Trust>,
pub trust_origin: Option<TrustOrigin>,
pub llm_inputs: Option<LlmInputs>,
}Expand description
Fully resolved specification for a step scheduled by the runtime.
Fields
id: StepIdtype: StepTypeinputs: Valuepolicy: Valueexecution: StepExecutionslug: Option<String>trust: Option<Trust>trust_origin: Option<TrustOrigin>llm_inputs: Option<LlmInputs>Implementations
Sourceimpl StepSpec
impl StepSpec
Sourcepub fn try_from_value(value: Value) -> Result<Self, StepSpecDecodeError>
pub fn try_from_value(value: Value) -> Result<Self, StepSpecDecodeError>
Validates a JSON blob, enriches it with derived fields, and returns a StepSpec.